Struct taple_core::NodeSettings
source · pub struct NodeSettings {
pub key_derivator: KeyDerivator,
pub secret_key: String,
pub digest_derivator: DigestDerivator,
pub replication_factor: f64,
pub timeout: u32,
pub smartcontracts_directory: String,
/* private fields */
}Expand description
General settings of a TAPLE node.
Fields
key_derivator: KeyDerivatorKeyDerivator to be used by the secret key.
secret_key: StringSecret key to be used by the node
digest_derivator: DigestDerivatorDigestDerivator to be used for future event and subject identifiers
replication_factor: f64Percentage of network nodes receiving protocol messages in one iteration
timeout: u32Timeout to be used between protocol iterations
smartcontracts_directory: StringTrait Implementations
sourceimpl Clone for NodeSettings
impl Clone for NodeSettings
sourcefn clone(&self) -> NodeSettings
fn clone(&self) -> NodeSettings
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NodeSettings
impl Debug for NodeSettings
sourceimpl Default for NodeSettings
impl Default for NodeSettings
sourceimpl<'de> Deserialize<'de> for NodeSettings
impl<'de> Deserialize<'de> for NodeSettings
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more